@@ -6,11 +6,11 @@ use DBI ();
 
 use strict;
 
-#$Id: AuthenDBI.pm,v 1.10 1997/08/15 13:33:44 mergl Exp $
+#$Id: AuthenDBI.pm,v 1.15 1997/11/02 18:25:58 mergl Exp $
 
 require_version DBI 0.85;
 
-$Apache::AuthenDBI::VERSION = '0.74';
+$Apache::AuthenDBI::VERSION = '0.75';
 
 $Apache::AuthenDBI::DEBUG = 0;
 
@@ -27,6 +27,7 @@ my %Config = (
     'Auth_DBI_authoritative'  => 'on',
     'Auth_DBI_nopasswd'       => 'off',
     'Auth_DBI_encrypted'      => 'on',
+    'Auth_DBI_casesensitive'  => 'on',
 );
 
 sub handler {
@@ -82,6 +83,13 @@ sub handler {
         return SERVER_ERROR;
     }
 
+    # Do we want Windows-like case-insensitivity?
+    if ($attr->{casesensitive} eq "off")
+    {
+       $user_sent   = lc($user_sent);
+       $passwd_sent = lc($passwd_sent);
+    }
+
     $user_sent  = $dbh->quote($user_sent);
 
     my $statement = "SELECT $attr->{pwd_field} FROM $attr->{pwd_table} WHERE $attr->{uid_field}=$user_sent";
@@ -103,6 +111,9 @@ sub handler {
 
     # fetch result
     my ($passwd) = $sth->fetchrow_array;
+
+    # strip trailing blanks for fixed-length datatype
+    $passwd =~ s/ +$//;
     print STDERR "$prefix passwd = >$passwd<\n" if $Apache::AuthenDBI::DEBUG;
 
     $sth->finish;
@@ -309,6 +320,12 @@ to be crypted using perl's crypt() function and the incoming password is
 crypted before comparison. When this directive is set to 'off', the comparison 
 is done directly with the plain-text entered password. 
 
+=item *
+Auth_DBI_casesensitive  < on / off >
+
+Default is 'on'. When set 'off', the entered userid and password is converted 
+to lower case. 
+
 
 =head1 CONFIGURATION
 
