@@ -3,11 +3,11 @@ package Apache::DBI;
 use DBI ();
 use strict;
 
-#$Id: DBI.pm,v 1.5 1997/08/15 13:33:45 mergl Exp $
+#$Id: DBI.pm,v 1.16 1997/11/02 18:25:59 mergl Exp $
 
 require_version DBI 0.85;
 
-$Apache::DBI::VERSION = '0.74';
+$Apache::DBI::VERSION = '0.75';
 
 $Apache::DBI::DEBUG = 0;
 
@@ -20,7 +20,15 @@ sub connect {
     unshift @_, $class if ref $class;
     my $drh  = shift;
     my @args = map { defined $_ ? $_ : "" } @_;
-    my $idx  = join (":", (@args));
+    my $idx  = "$args[0]:$args[1]:$args[2]";
+
+    # the hash_ref differs between calls even in the same process
+    my ($key, $val);
+    if (3 == $#args && ref $args[3] eq "HASH") {
+       while (($key,$val) = each %{$args[3]}) {
+           $idx .= ":$key=$val";
+       }
+    }
 
     if (($Connected{$idx} && $Connected{$idx}->ping)) {
         print STDERR "$$ Apache::DBI already connected to '$idx'\n" if $Apache::DBI::DEBUG;
@@ -30,7 +38,6 @@ sub connect {
     $Connected{$idx} = undef;
     $Connected{$idx} = $drh->connect(@args);
     return undef if ! $Connected{$idx};
-    $Connected{$idx}->{InactiveDestroy} = 1;
     print STDERR "$$ Apache::DBI new connect to '$idx'\n" if $Apache::DBI::DEBUG;
     return (bless $Connected{$idx}, 'Apache::DBI::db');
 }
